==> videosdk-0.0.7-py3-none-any.whl: videosdk/event_handler.py <==
import logging
from typing import final


class BaseEvent:
    """
    VideoSDK BaseEvent Class
    """

    @final
    def handle_event(self, action, data):
        method_name = {
            # Base Event Handlers
            "error": "on_error",

            # Meeting Event Handlers
            "meeting-joined": "on_meeting_joined",
            "meeting-left": "on_meeting_left",
            "participant-mode-changed": "on_participant_mode_changed",
            "participant-joined": "on_participant_joined",
            "participant-left": "on_participant_left",
            "speaker-changed": "on_speaker_changed",
            "presenter-changed": "on_presenter_changed",
            "main-participant-changed": "on_main_participant_changed",
            "chat-message": "on_chat_message",
            "entry-requested": "on_entry_requested",
            "entry-responded": "on_entry_responded",
            "recording-state-changed": "on_recording_state_changed",
            "recording-started": "on_recording_started",
            "recording-stopped": "on_recording_stopped",
            "whiteboard-started": "on_whiteboard_started",
            "whiteboard-stopped": "on_whiteboard_stopped",
            "video-state-changed": "on_video_state_changed",
            "mic-requested": "on_mic_requested",
            "webcam-requested": "on_webcam_requested",
            "pin-state-changed": "on_pin_state_changed",
            "connection-open": "on_connection_open",
            "connection-close": "on_connection_close",
            "meeting-state-changed": "on_meeting_state_change",
            "transcription-state-changed": "on_transcription_state_changed",
            "transcription-text": "on_transcription_text",

            # Participant Event Handlers
            "stream-enabled": "on_stream_enabled",
            "stream-disabled": "on_stream_disabled",
            "media-status-changed": "on_media_status_changed",
            "video-quality-changed": "on_video_quality_changed"
        }.get(action, None)

        if method_name is None:
            logging.debug(f"unimplemented event handler {action}")
            return

        method = getattr(self, method_name, None)
        if method:
            method(data)
        else:
            logging.debug(f"No method found for {method_name}")


class MeetingEventHandler(BaseEvent):
    def on_error(self, data):
        """
        Handle error event.
        """

    def on_meeting_joined(self, data) -> None:
        """
        Handle meeting joined event.
        """

    def on_meeting_left(self, data) -> None:
        """
        Handle meeting left event.
        """

    def on_participant_mode_changed(self, data):
        """
        Handle participant mode changed event.
        """

    def on_participant_joined(self, participant):
        """
        Handle participant joined event.
        """

    def on_participant_left(self, participant):
        """
        Handle participant left event.
        """

    def on_speaker_changed(self, data):
        """
        Handle speaker changed event.
        """

    def on_recording_state_changed(self, data):
        """
        Handle recording state changed event.
        """

    def on_recording_started(self, data):
        """
        Handle recording started event.
        """

    def on_recording_stopped(self, data):
        """
        Handle recording stopped event.
        """

    def on_mic_requested(self, data):
        """
        Handle microphone requested event.
        """

    def on_webcam_requested(self, data):
        """
        Handle webcam requested event.
        """

    def on_meeting_state_change(self, data):
        """
        Handle meeting state change event.
        """

    def on_transcription_state_changed(self, data):
        """
        Handle transcription state changed event.
        """

    def on_transcription_text(self, data):
        """
        Handle transcription text event.
        """


class ParticipantEventHandler(BaseEvent):
    def on_stream_enabled(self, stream) -> None:
        """
        Handle Participant stream enabled event.
        """

    def on_stream_disabled(self, stream) -> None:
        """
        Handle Participant stream enabled event.
        """

    def on_media_status_changed(self, data) -> None:
        """
        Handle Participant stream enabled event.
        """

    def on_video_quality_changed(self, data) -> None:
        """
        Handle Participant stream enabled event.
        """

==> videosdk-0.0.12-py3-none-any.whl: videosdk/event_handler.py <==
import logging
from typing import final

logger = logging.getLogger(__name__)


class BaseEvent:
    """
    VideoSDK BaseEvent Class
    """

    @final
    def handle_event(self, action, data):
        method_name = {
            # Base Event Handlers
            "error": "on_error",
            # Meeting Event Handlers
            "meeting-joined": "on_meeting_joined",
            "meeting-left": "on_meeting_left",
            "participant-mode-changed": "on_participant_mode_changed",
            "participant-joined": "on_participant_joined",
            "participant-left": "on_participant_left",
            "speaker-changed": "on_speaker_changed",
            "presenter-changed": "on_presenter_changed",
            "main-participant-changed": "on_main_participant_changed",
            "chat-message": "on_chat_message",
            "entry-requested": "on_entry_requested",
            "entry-responded": "on_entry_responded",
            "recording-state-changed": "on_recording_state_changed",
            "recording-started": "on_recording_started",
            "recording-stopped": "on_recording_stopped",
            "whiteboard-started": "on_whiteboard_started",
            "whiteboard-stopped": "on_whiteboard_stopped",
            "video-state-changed": "on_video_state_changed",
            "mic-requested": "on_mic_requested",
            "webcam-requested": "on_webcam_requested",
            "pin-state-changed": "on_pin_state_changed",
            "connection-open": "on_connection_open",
            "connection-close": "on_connection_close",
            "meeting-state-changed": "on_meeting_state_change",
            "transcription-state-changed": "on_transcription_state_changed",
            "transcription-text": "on_transcription_text",
            # Participant Event Handlers
            "stream-enabled": "on_stream_enabled",
            "stream-disabled": "on_stream_disabled",
            "media-status-changed": "on_media_status_changed",
            "video-quality-changed": "on_video_quality_changed",
        }.get(action, None)

        if method_name is None:
            logger.debug(f"unimplemented event handler {action}")
            return

        method = getattr(self, method_name, None)
        if method:
            method(data)
        else:
            logger.debug(f"No method found for {method_name}")


class MeetingEventHandler(BaseEvent):
    def on_error(self, data):
        """
        Handle error event.
        """

    def on_meeting_joined(self, data) -> None:
        """
        Handle meeting joined event.
        """

    def on_meeting_left(self, data) -> None:
        """
        Handle meeting left event.
        """

    def on_participant_mode_changed(self, data):
        """
        Handle participant mode changed event.
        """

    def on_participant_joined(self, participant):
        """
        Handle participant joined event.
        """

    def on_participant_left(self, participant):
        """
        Handle participant left event.
        """

    def on_speaker_changed(self, data):
        """
        Handle speaker changed event.
        """

    def on_recording_state_changed(self, data):
        """
        Handle recording state changed event.
        """

    def on_recording_started(self, data):
        """
        Handle recording started event.
        """

    def on_recording_stopped(self, data):
        """
        Handle recording stopped event.
        """

    def on_mic_requested(self, data):
        """
        Handle microphone requested event.
        """

    def on_webcam_requested(self, data):
        """
        Handle webcam requested event.
        """

    def on_meeting_state_change(self, data):
        """
        Handle meeting state change event.
        """

    def on_transcription_state_changed(self, data):
        """
        Handle transcription state changed event.
        """

    def on_transcription_text(self, data):
        """
        Handle transcription text event.
        """


class ParticipantEventHandler(BaseEvent):
    def on_stream_enabled(self, stream) -> None:
        """
        Handle Participant stream enabled event.
        """

    def on_stream_disabled(self, stream) -> None:
        """
        Handle Participant stream enabled event.
        """

    def on_media_status_changed(self, data) -> None:
        """
        Handle Participant stream enabled event.
        """

    def on_video_quality_changed(self, data) -> None:
        """
        Handle Participant stream enabled event.
        """
